@@ -110,7 +110,7 @@ def convert_to_clever_object(klass, resp, api_key):
       return [convert_to_clever_object(klass, i, api_key) for i in resp['data']]
     elif isinstance(resp['data'], dict):
       return klass.construct_from(resp['data'].copy(), api_key)
-  elif isinstance(resp, basestring) or isinstance(resp, list) or isinstance(resp, dict):
+  elif isinstance(resp, basestring) or isinstance(resp, list) or isinstance(resp, dict) or isinstance(resp, bool):
     return resp
   else:
     raise Exception('DONT KNOW WHAT TO DO WITH {0}'.format(resp))
@@ -228,7 +228,7 @@ class APIRequestor(object):
       rbody, rcode = self.urllib2_request(meth, abs_url, headers, params)
     else:
       raise CleverError("Clever Python library bug discovered: invalid httplib %s.  Please report to support@getclever.com" % (_httplib, ))
-    logger.info('API request to %s returned (response code, response body) of (%d, %r)' % (abs_url, rcode, rbody))
+    logger.debug('API request to %s returned (response code, response body) of (%d, %r)' % (abs_url, rcode, rbody))
     return rbody, rcode, my_api_key
 
   def interpret_response(self, rbody, rcode):
